@@ -6,9 +6,9 @@ x <- moduleMetadata(sampleModules[3], path)
 mySim <- simInit(
    times = list(start = 2000.0, end = 2002.0, timeunit = "year"),
    params = list(
-     .globals = list(stackName = "landscape", burnStats = "nPixelsBurned")
+     .globals = list(stackName = "landscape")
    ),
-   modules = list("randomLandscapes", "fireSpread", "caribouMovement"),
+   modules = list("caribouMovement"),
    paths = list(modulePath = system.file("sampleModules", package = "SpaDES.core"))
 )
 moduleMetadata(sim = mySim)
